def eval(script :str) -> object:
	"""
	执行JS片段。
	"""
	pass
def exec_file(filePath :str) -> object:
	"""
	执行JS脚本。
	"""
	pass
def rmi(addr :str) -> object:
	"""
	连接JSRMI服务。
	"""
	pass
class JSRMI:
	def close(self) -> object:
		"""
		关闭连接。
		"""
		pass
	def eval(self,cmd :str) -> object:
		"""
		执行命令。
		"""
		pass
	pass


class Manager:
	def __init__(self,distribute :object,execute :object) -> object:
		"""
		实例化多线程管理器。需要提供分发函数与执行函数。
		"""
		pass
	def handle_result(self,middleware :object) -> object:
		"""
		设置结果收集中间件。
		"""
		pass
	def handle_error(self,f :object) -> object:
		"""
		设置错误处理函数。
		"""
		pass
	def run(self,threads :int) -> object:
		"""
		启动。
		"""
		pass
	pass
class DistributeController:
	def stop(self) -> object:
		"""
		停止执行。
		"""
		pass
	def add_task(self,a :object) -> object:
		"""
		增加任务。
		"""
		pass
	pass
class ExecuteController:
	def stop(self) -> object:
		"""
		停止执行。
		"""
		pass
	def retry(self,a :object) -> object:
		"""
		重试任务。
		"""
		pass
	pass


def base64_decode(data :str) -> object:
	"""
	Base64解码。
	"""
	pass
def gzip_decode(data :object) -> object:
	"""
	Gzip解码。
	"""
	pass
def json_loads(data :str) -> object:
	"""
	加载并解析Json字符串。
	"""
	pass
def wxapkg_decode(wxid :str,data :str) -> object:
	"""
	WXApkg解码。
	"""
	pass
def md5(s :str) -> str:
	"""
	计算字符串的md5值
	"""
	pass
def url_encode(urlStr :str) -> str:
	"""
	URL编码。
	"""
	pass
def gzip_encode(data :str) -> object:
	"""
	Gzip编码。
	"""
	pass
def json_dumps(a :object) -> str:
	"""
	将一个对象序列化为Json字符串。
	"""
	pass
def url_decode(urlStr :str) -> str:
	"""
	URL解码。
	"""
	pass
def base64_encode(data :str) -> str:
	"""
	Base64编码。
	"""
	pass


def new_ssh(addr :str,username :str,passwdOrId_rsa :str) -> object:
	"""
	连接ssh。
	"""
	pass
def request(method :str,targetUrl :str,params :object,data :object,headers :object,verify :bool,proxyStr :str,timeout :int) -> object:
	"""
	发起请求。
	"""
	pass
def ssh(addr :str,username :str,passwdOrId_rsa :str) -> None:
	"""
	连接ssh。
	"""
	pass
def ssh_run(addr :str,username :str,passwdOrId_rsa :str,command :str) -> None:
	"""
	通过ssh执行命令。
	"""
	pass
def ssh_exec(addr :str,username :str,passwdOrId_rsa :str,command :str) -> str:
	"""
	通过ssh执行命令并获取执行结果。
	"""
	pass
GET= None #GET Method
POST= None #POST Method
class SSH:
	def exec_command(self,command :str) -> str:
		"""
		执行命令。
		"""
		pass
	def close(self) -> object:
		"""
		关闭连接。
		"""
		pass
	pass
class HTTPRequest:
	def __init__(self,data :object) -> object:
		"""
		实例化一个HTTP请求对象。
		"""
		pass
	def header(self,header :object) -> object:
		"""
		获取或设置请求头。
		"""
		pass
	def body(self,body :object) -> object:
		"""
		获取或设置请求体。
		"""
		pass
	def raw_query(self,query :object) -> str:
		"""
		获取原始query。
		"""
		pass
	def method(self,method :object) -> str:
		"""
		获取或设置请求方式。
		"""
		pass
	def proto(self,p :object) -> str:
		"""
		获取或设置协议。
		"""
		pass
	def to_request(self) -> object:
		"""
		——
		"""
		pass
	def path(self,path :object) -> str:
		"""
		获取路径。
		"""
		pass
	def query(self,k :object,v :object,diableCover :bool) -> object:
		"""
		获取或获取请求中的GET参数。
		"""
		pass
	def url(self) -> str:
		"""
		获取URL。
		"""
		pass
	pass
class HTTPResponse:
	def __init__(self,data :object,req :object) -> object:
		"""
		实例化一个HTTP响应对象。
		"""
		pass
	def to_response(self) -> object:
		"""
		——
		"""
		pass
	def status(self,text :object) -> str:
		"""
		获取或设置状态。
		"""
		pass
	def status_code(self,code :object) -> int:
		"""
		获取或设置状态码。
		"""
		pass
	def header(self,header :object) -> object:
		"""
		获取或设置响应头。
		"""
		pass
	def body(self,body :object) -> object:
		"""
		获取或设置响应体。
		"""
		pass
	def request(self) -> object:
		"""
		获取生成该响应的请求。
		"""
		pass
	pass
class HTTPProxyServer:
	def __init__(self,handleReq :object,handleResp :object,caRootPath :str) -> object:
		"""
		实例化一个HTTP代理对象。
		"""
		pass
	def start(self,addr :str,proxy :str,verbose :bool) -> None:
		"""
		启动代理。
		"""
		pass
	pass
class WebSocketServer:
	def __init__(self,handler :object,welcome :str) -> object:
		"""
		实例化一个WebSocket服务对象。
		"""
		pass
	def start(self,addr :str,path :str) -> None:
		"""
		启动WebSocket。
		"""
		pass
	pass


GREEN= None #绿色
BLUE= None #蓝色
YELLOW= None #黄色
RFC1123Z= None #Mon, 02 Jan 2006 15:04:05 -0700
def echo(text :object,color :object,end :object) -> object:
	"""
	带有颜色的print，会打印解释器内部的结构。
	"""
	pass
def bytes(data :object) -> object:
	"""
	转换数据类型为bytes。
	"""
	pass
def parse_time(layout :str,value :str) -> object:
	"""
	解析时间字符串，返回Unix时间戳。
	"""
	pass
RFC3339Nano= None #2006-01-02T15:04:05.999999999Z07:00
RFC822Z= None #02 Jan 06 15:04 -0700
RFC850= None #Monday, 02-Jan-06 15:04:05 MST
def input(prefix :str,color :object,title :str,history :object,completer :object) -> str:
	"""
	支持补全的输入。
	"""
	pass
GRAY= None #灰色
CYAN= None #青色
WHITE= None #白色
RFC3339= None #2006-01-02T15:04:05Z07:00
RFC822= None #02 Jan 06 15:04 MST
def render(parts :object) -> str:
	"""
	按照“颜色、字符串、颜色、字符串……“的循环模式生成多彩的字符串。
	"""
	pass
def string(data :object) -> str:
	"""
	转换数据类型为string。
	"""
	pass
def random_num(max :int) -> int:
	"""
	生成从0到指定最大值的随机数。
	"""
	pass
RED= None #红色
BLACK= None #黑色
MAGENTA= None #洋红色
RFC1123= None #Mon, 02 Jan 2006 15:04:05 MST


def is_file(path :str) -> bool:
	"""
	判断路径是否指向一个文件。
	"""
	pass
def wxapkg_unpack(decryptedData :str,beautify :bool,thread :int) -> object:
	"""
	对wxapkg字符串解码得到文件。
	"""
	pass
def save_excel(filePath :str,sheets :object) -> None:
	"""
	将Excel对象保存至路径。
	"""
	pass
def tag_extract(data :str) -> object:
	"""
	从字符串中提取所有标签。
	"""
	pass
def read_file(filePath :str) -> str:
	"""
	读取文件内容。
	"""
	pass
def walk_dir(pathname :str,suffix :str,recursion :bool) -> object:
	"""
	遍历指定目录下的所有文件及文件夹。默认不递归。
	"""
	pass
def toml_dump(s :object) -> str:
	"""
	将对象序列化为Toml字符串。
	"""
	pass
def load_excel(filePath :str,numList :bool) -> object:
	"""
	加载一个Excel表格。
	"""
	pass
def save_file(path :str,content :str,cover :bool) -> None:
	"""
	保存内容到指定路径。不存在会创建，默认不覆盖。
	"""
	pass
def is_dir(path :str) -> bool:
	"""
	判断路径是否指向一个文件夹。
	"""
	pass
def toml_loads(data :str) -> object:
	"""
	加载并解析Toml字符串。
	"""
	pass
class Excel:
	def __init__(self) -> object:
		"""
		实例化Excel对象。
		"""
		pass
	def get_sheet_names(self) -> object:
		"""
		获取所有表格的名字。
		"""
		pass
	def set_sheet(self,name :str,sheet :object) -> object:
		"""
		放置一个表格到Excel。
		"""
		pass
	def get_sheet(self,name :str) -> object:
		"""
		获取指定表格。
		"""
		pass
	pass
class Sheet:
	def __init__(self) -> object:
		"""
		实例化Sheet对象。
		"""
		pass
	def get_key_list(self) -> object:
		"""
		获取表头。
		"""
		pass
	def set_key_list(self,list :object) -> object:
		"""
		设置表头。
		"""
		pass
	def set_data(self,line :int,rawData :object) -> None:
		"""
		按行号填充数据。行号从1开始。
		"""
		pass
	def get_all_data(self) -> object:
		"""
		获取表格中的所有数据。
		"""
		pass
	pass


def replace(text :str,old :str,new :str,num :int) -> str:
	"""
	字符串替换。
	:param text: 文本
	:param old: 原始字符串
	:param new: 替换字符串
	:param num: 替换次数，可省略，默认-1为全部替换
	:return:
	"""
	pass
def bracket(text :str,pairsRaw :object) -> bool:
	"""
	检查字符串中的括号是否闭合。
	"""
	pass
def cut(text :str,sep :str,reverse :bool) -> tuple[str,str]:
	"""
	将字符串按指定字符串切分为两部分。
	"""
	pass
def split(s :str,substr :str) -> object:
	"""
	将字符串按指定字符串切分为多个部分。
	"""
	pass
def format(s :str,args :object) -> str:
	"""
	格式化字符串，格式与go相同。
	"""
	pass
def join(parts :object,sep :str) -> str:
	"""
	以指定字符串为间隔拼接多个字符串。
	"""
	pass
def trim_left(s :str,cutset :str) -> str:
	"""
	移除字符串左侧所有包含在移除字符集中的字符。
	"""
	pass
def trim(s :str,cutset :str) -> str:
	"""
	移除字符串中所有包含在移除字符集中的字符。
	"""
	pass
def format_split(text :str,formatStr :str,leftSep :str,rightSep :str) -> object:
	"""
	按照指定模式在字符串中匹配符合模式的所有结果。
	"""
	pass
def match(text :str,left :str,right :str,whole :bool) -> object:
	"""
	匹配文本中满足条件的全部文本。
	:param left: 左侧文本 
	:param right: 右侧文本
	:param text: 需要匹配的文本
	:return: 返回包含结果的字符串列表
	"""
	pass
def is_upper(s :str) -> bool:
	"""
	检查一个字符串首字母是否大写。
	"""
	pass
def trim_right(s :str,cutset :str) -> str:
	"""
	移除字符串右侧所有包含在移除字符集中的字符。
	"""
	pass
def pascal_to_snake(s :str) -> str:
	"""
	将驼峰字符串转为蛇形。
	Eg. AaBbCc -> aa_bb_cc
	"""
	pass